package app.data.service;

import app.data.bean.CalculatedMatch;
import app.data.bean.PlayerForTable;
import app.data.entity.Match;
import app.data.entity.Matchday;
import app.data.entity.Player;
import app.data.entity.Season;
import app.data.repository.PlayerRepository;
import app.navigation.NavigableService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.vaadin.artur.helpers.CrudService;

import java.util.*;
import java.util.function.Function;
import java.util.function.Predicate;
import java.util.stream.Collectors;
import java.util.stream.Stream;

@Service
public class PlayerService extends CrudService<Player, Integer> implements NavigableService<Player> {

    private final PlayerRepository repository;

    private final MatchdayService matchdayService;
    private final MatchService matchService;

    public PlayerService(@Autowired PlayerRepository repository, @Autowired MatchdayService matchdayService, @Autowired MatchService matchService) {
        this.repository = repository;
        this.matchdayService = matchdayService;
        this.matchService = matchService;
    }

    @Override
    protected PlayerRepository getRepository() {
        return repository;
    }

    public List<PlayerForTable> getPlayersForTable(Matchday matchday) {
        return new PlayerForTableProvider(this, matchdayService, matchday).getPlayersForTableSorted(true);
    }

    public List<Player> getAllPlayersSorted() {
        return repository.findAll().stream()
                .sorted((player1, player2) -> player1.getNickname().compareToIgnoreCase(player2.getNickname()))
                .collect(Collectors.toList());
    }

    @Override
    public Class<Player> getNavigableClass() {
        return Player.class;
    }

    public List<CalculatedMatch> getCalculatedMatchesSorted(Player player, Season season) {
        return matchdayService.getMatchdaysSorted(season).stream()
                .flatMap(matchday -> matchday.getMatches().stream())
                .distinct()
                .filter(match -> match.getPlayer1().equals(player) || match.getPlayer2().equals(player))
                .map(matchService::getCalculatedMatch)
                .collect(Collectors.toList());
    }

}
