package app.gameimage;

import app.data.chesscom.ChessComGame;
import app.data.entity.Game;
import app.data.service.ChessComService;
import com.vaadin.flow.component.html.Image;
import com.vaadin.flow.server.StreamResource;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.util.Optional;

import static app.gameimage.GameImageGenerator.generateImage;
import static app.gameimage.GameImageUtils.*;

@Service
public class GameImageService {

    private final ChessComService chessComService;

    public GameImageService(@Autowired ChessComService chessComService) {
        this.chessComService = chessComService;
    }


    public boolean hasImage(Game game) {
        String path = IMAGE_DEST_DIR + getGameId(game) + EXTENSION;
        File f = new File(path);
        return f.isFile();
    }

    public void createImageIfNotPresent(Game game) {
        if (hasImage(game)) return;
        getPgn(game).ifPresent(pgn -> GameImageUtils.writeImage(generateImage(pgn), getGameId(game)));
    }

    public Image getImage(Game game, String alt) {
        StreamResource resource = new StreamResource(getImageFilename(game), () -> new ByteArrayInputStream(getImageBytes(game)));
        return new Image(resource, alt);
    }

    private Optional<String> getPgn(Game game) {
        if (game.getGameInfo().getPgn() != null) return Optional.of(game.getGameInfo().getPgn());
        return chessComService.getChessComGame(game).map(ChessComGame::getPgn);
    }

}
