package app.navigation.matchday;

import app.data.entity.Matchday;
import app.data.entity.Season;
import app.data.service.MatchdayService;
import app.data.service.SeasonService;
import app.navigation.Navigable;
import app.navigation.Navigation;
import com.vaadin.flow.component.select.Select;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.lang.NonNull;
import org.springframework.lang.Nullable;

import java.util.List;
import java.util.Optional;

public class MatchdayNavigation extends Navigation {

    private boolean onlyMatchdaysWithActivity;

    MatchdayNavigation(@Autowired SeasonService seasonService,
                       @Autowired MatchdayService matchdayService) {
        super(seasonService, matchdayService);
    }

    public void setOnlyMatchdaysWithActivity(boolean onlyMatchdaysWithActivity) {
        this.onlyMatchdaysWithActivity = onlyMatchdaysWithActivity;
    }

    @Override
    @SuppressWarnings({"unchecked", "DuplicatedCode"}) // TODO: get rid of duplications
    protected <PARENT extends Navigable, CHILD extends Navigable> List<CHILD> getChildren(@Nullable PARENT parent, @NonNull Class<CHILD> childClass) {
        if (childClass.equals(Season.class)) {
            return (List<CHILD>) getSeasonService().getAllSeasonsSorted();
        }
        if (childClass.equals(Matchday.class)) {
            assert parent != null;
            if (onlyMatchdaysWithActivity)
                return (List<CHILD>) getMatchdayService().getMatchdaysWithActivitySortedOrElseListWithOnlyFirstMatchday((Season) parent);
            return (List<CHILD>) getMatchdayService().getMatchdaysSorted((Season) parent);
        }
        throw new UnsupportedOperationException(String.format("This method is not supported for childClass %s", childClass.getSimpleName()));
    }

    @Override
    @SuppressWarnings({"unchecked", "DuplicatedCode"}) // TODO: get rid of duplications
    protected <T extends Navigable> T getDefaultValue(Class<T> clazz) {
        if (clazz.equals(Season.class)) {
            assert !getSeasonList().isEmpty();
            return (T) getSeasonList().get(getSeasonList().size() - 1);
        }
        if (clazz.equals(Matchday.class)) {
            assert !getMatchdayList().isEmpty();
            Matchday matchdayToSelect = getMatchdayList().get(0);
            for (Matchday matchday : getMatchdayList())
                if (getMatchdayService().hasActivity(matchday)) matchdayToSelect = matchday;
            return (T) matchdayToSelect;
        }
        throw new UnsupportedOperationException(String.format("This method is not supported for clazz %s", clazz.getSimpleName()));
    }

    public SeasonService getSeasonService() {
        return (SeasonService) serviceMap.get(Season.class);
    }

    public MatchdayService getMatchdayService() {
        return (MatchdayService) serviceMap.get(Matchday.class);
    }

    @SuppressWarnings("unchecked")
    public List<Season> getSeasonList() {
        return (List<Season>) listMap.get(Season.class);
    }

    @SuppressWarnings("unchecked")
    public List<Matchday> getMatchdayList() {
        return (List<Matchday>) listMap.get(Matchday.class);
    }

    @SuppressWarnings("unchecked")
    public Select<Season> getSeasonSelect() {
        return (Select<Season>) selectMap.get(Season.class);
    }

    @SuppressWarnings("unchecked")
    public Select<Matchday> getMatchdaySelect() {
        return (Select<Matchday>) selectMap.get(Matchday.class);
    }

    public Optional<Matchday> getSelectedMatchday() {
        return getMatchdaySelect().getOptionalValue();
    }

    public Optional<Season> getSelectedSeason() {
        return getSeasonSelect().getOptionalValue();
    }
}
