package app.navigation.matchday.components.button;

import app.data.entity.Matchday;
import app.navigation.matchday.MatchdayNavigation;
import com.vaadin.flow.component.button.Button;
import com.vaadin.flow.component.icon.VaadinIcon;

import java.util.Optional;

public class NextMatchdayButton extends Button {

    private final MatchdayNavigation matchdayNavigation;

    public NextMatchdayButton(MatchdayNavigation matchdayNavigation) {
        this.matchdayNavigation = matchdayNavigation;

        setIcon(VaadinIcon.ARROW_RIGHT.create());

        matchdayNavigation.addRunnableToBeRunAfterSelection(this::configure);
    }

    private void configure() {
        Optional<Matchday> nextMatchday = getNextMatchday();
        setEnabled(nextMatchday.isPresent());
        addClickListener(event -> nextMatchday.ifPresent(matchday -> matchdayNavigation.getMatchdaySelect().setValue(matchday)));
    }

    private Optional<Matchday> getNextMatchday() {
        int index = MatchdayButtonUtils.getMatchdayIndex(matchdayNavigation);
        if (index >= 0 && index < matchdayNavigation.getMatchdayList().size() - 1)
            return Optional.ofNullable(matchdayNavigation.getMatchdayList().get(index + 1));
        return Optional.empty();
    }
}
