package app.navigation.player.components.button;

import app.data.entity.Player;
import app.navigation.player.PlayerNavigation;
import com.vaadin.flow.component.button.Button;
import com.vaadin.flow.component.icon.VaadinIcon;

import java.util.List;
import java.util.Optional;

public class NextPlayerButton extends Button {

    private final PlayerNavigation playerNavigation;

    public NextPlayerButton(PlayerNavigation playerNavigation) {
        this.playerNavigation = playerNavigation;

        setIcon(VaadinIcon.ARROW_RIGHT.create());

        playerNavigation.addRunnableToBeRunAfterSelection(this::configure);
    }

    private void configure() {
        Optional<Player> nextPlayer = getNextPlayer();
        setEnabled(nextPlayer.isPresent());
        addClickListener(event -> nextPlayer.ifPresent(player -> playerNavigation.getPlayerSelect().setValue(player)));
    }

    private Optional<Player> getNextPlayer() {
        int index = PlayerButtonUtils.getPlayerIndex(playerNavigation);
        if (index >= 0) {
            List<Player> playerList = playerNavigation.getPlayerList();
            return Optional.of(playerList.get(Math.floorMod(index + 1, playerList.size())));
        }
        return Optional.empty();
    }
}
