package app.utils;

import app.data.chesscom.ChessComGame;
import app.data.entity.Game;
import app.data.entity.Match;
import app.data.entity.Player;
import org.springframework.lang.NonNull;

import static app.utils.TimeControl.*;

public class ChessComUtils {

    private static final String GAME_LINK = "https://www.chess.com/game/live/{gameId}";

    private ChessComUtils() {
    }

    public static String getPreparedArchiveJson(String unpreparedArchiveJson) {
        return unpreparedArchiveJson
                .replace("@id", "id")
                .replace("end_time", "endTime")
                .replace("time_class", "timeClass")
                .replace("time_control", "timeControl");
    }

    public static String getUsernameForUrl(Player player) {
        return player.getNickname().toLowerCase();
    }

    public static int getResult(ChessComGame chessComGame) {
        if (chessComGame.getWhite().getResult().equals("win")) {
            return 1;
        }
        if (chessComGame.getBlack().getResult().equals("win")) {
            return -1;
        }
        return 0;
    }

    public static boolean isGameBetweenPlayers(@NonNull ChessComGame game, @NonNull Match match) {
        String white = game.getWhite().getUsername();
        String black = game.getBlack().getUsername();
        String name1 = match.getPlayer1().getNickname();
        String name2 = match.getPlayer2().getNickname();
        return (white.equals(name1) || white.equals(name2)) && (black.equals(name1) || black.equals(name2));
    }

    public static boolean hasValidTimeControl(ChessComGame game) {
        String timeControl = game.getTimeControl();
        if (timeControl != null) {
            return timeControl.equals(TEN_MINUTES.toSecondsString())
                    || timeControl.equals(FIVE_MINUTES.toSecondsString())
                    || timeControl.equals(THREE_MINUTES.toSecondsString());
        }
        return false;
    }

    public static String getGameURL(Game game) {
        String gameId = game.getGameInfo().getChessComId();
        return getGameURL(gameId);
    }

    public static String getGameURL(String gameId) {
        return GAME_LINK.replace("{gameId}", gameId);
    }

    public static String getGameId(ChessComGame game) {
        String[] fields = game.getUrl().split("/");
        return fields[fields.length - 1];
    }
}
