package app.utils;

import app.data.entity.Player;
import app.data.entity.Season;
import app.views.player.PlayerView;
import com.vaadin.flow.component.Component;
import com.vaadin.flow.component.html.Anchor;
import com.vaadin.flow.component.html.Label;
import com.vaadin.flow.component.orderedlayout.FlexComponent;
import com.vaadin.flow.component.orderedlayout.HorizontalLayout;
import com.vaadin.flow.router.RouterLink;

public class ComponentUtils {
    private ComponentUtils() {
    }

    public static void configurePlayerLabel(HorizontalLayout layout, Player player, Season season) {
        String param = String.format("%s/%s/", EntityStringUtils.getPlayerStringForURL(player), EntityStringUtils.getSeasonStringForURL(season));
        RouterLink playerLink = new RouterLink(player.getName(), PlayerView.class, param);
        playerLink.addClassName("bold-label");

        Anchor chessComLink = new Anchor(player.getPlayerInfo().getUrl(), player.getNickname());
        chessComLink.setTarget("_blank");
        chessComLink.addClassName("no-margin-left");

        configureFormattedComponentsWithParentheses(layout, playerLink, chessComLink);
    }

    public static HorizontalLayout getPlayerLabel(Player player, Season season, boolean center) {
        HorizontalLayout layout = new HorizontalLayout();
        configurePlayerLabel(layout, player, season);

        if (center) {
            layout.setWidthFull();
            layout.setJustifyContentMode(FlexComponent.JustifyContentMode.CENTER);
        }

        return layout;
    }

    public static HorizontalLayout getFormattedLabelWithParentheses(String mainText, String textInParentheses) {
        HorizontalLayout horizontalLayout = new HorizontalLayout();
        configureFormattedLabelWithParentheses(horizontalLayout, mainText, textInParentheses);
        return horizontalLayout;
    }

    public static void configureFormattedLabelWithParentheses(HorizontalLayout horizontalLayout, String mainText, String textInParentheses) {
        Label mainLabel = new Label(mainText);
        mainLabel.addClassName("bold-label");

        Label parentheseslabel = new Label(textInParentheses);
        parentheseslabel.addClassName("no-margin-left");

        configureFormattedComponentsWithParentheses(horizontalLayout, mainLabel, parentheseslabel);
    }

    public static void configureFormattedComponentsWithParentheses(HorizontalLayout horizontalLayout, Component mainComponent, Component parenthesesComponent) {

        Label leftParenthesis = new Label("(");
        leftParenthesis.addClassName("parentheses-label");
        Label rightParenthesis = new Label(")");
        rightParenthesis.addClassName("no-margin-left");

        horizontalLayout.removeAll();
        horizontalLayout.add(mainComponent, leftParenthesis, parenthesesComponent, rightParenthesis);
    }
}
