package app.views.match;

import app.data.service.ChessComService;
import app.gameimage.GameImageService;
import app.navigation.match.MatchNavigation;
import app.navigation.match.MatchNavigationService;
import app.views.main.MainView;
import app.views.match.components.MatchComponent;
import app.views.navigation.NavigationViewBase;
import com.vaadin.flow.component.dependency.CssImport;
import com.vaadin.flow.router.PageTitle;
import com.vaadin.flow.router.Route;
import org.springframework.beans.factory.annotation.Autowired;

@CssImport("app/views/match/match-view.css")
@Route(value = "match", layout = MainView.class)
@PageTitle("Schachliga DACH - Results - Matches")
public class MatchView extends NavigationViewBase<MatchNavigation> {

    private final ChessComService chessComService;
    private final GameImageService gameImageService;
    private MatchComponent matchComponent;

    public MatchView(@Autowired MatchNavigationService matchNavigationService,
                     @Autowired ChessComService chessComService, GameImageService gameImageService) {
        super(matchNavigationService, "match");
        this.chessComService = chessComService;
        this.gameImageService = gameImageService;

        addClassName("match-view");

        configureLayout();
    }

    ////////////
    // LAYOUT //
    ////////////

    private void configureLayout() {
        matchComponent = new MatchComponent((MatchNavigation) navigation, chessComService, gameImageService);
        add(matchComponent);
    }

    /////////////
    // CONTENT //
    /////////////

    @Override
    protected void configureContent() {
        matchComponent.configureContent();
    }
}
