package app.views.navigation;

import app.navigation.NavigationHeader;
import app.navigation.Navigation;
import app.navigation.NavigationService;
import com.vaadin.flow.component.orderedlayout.FlexComponent;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;
import com.vaadin.flow.router.BeforeEvent;
import com.vaadin.flow.router.HasUrlParameter;
import com.vaadin.flow.router.WildcardParameter;
import org.springframework.beans.factory.annotation.Autowired;

public abstract class NavigationViewBase<T extends Navigation> extends VerticalLayout implements HasUrlParameter<String> {

    protected final Navigation navigation;
    protected final NavigationHeader<T> navigationHeader;

    @SuppressWarnings("unchecked")
    protected NavigationViewBase(@Autowired NavigationService<T> navigationService, String route) {
        this.navigation = navigationService.getNewNavigation();
        navigation.setRoute(route);
        this.navigationHeader = navigationService.getNewNavigationHeader((T) navigation);

        define();
    }

    private void define() {
        add(navigationHeader);
        addClassName("content");
        setAlignItems(FlexComponent.Alignment.CENTER);

        navigation.addRunnableToBeRunAfterSelection(this::configureContent);
    }

    /////////////
    // CONTENT //
    /////////////

    protected abstract void configureContent();

    //////////////
    // OVERRIDE //
    //////////////

    @Override
    public void removeAll() {
        super.removeAll();
        add(navigationHeader);
    }

    @Override
    public void setParameter(BeforeEvent event, @WildcardParameter String param) {
        navigation.setParameter(event, param);
    }
}
